#
# spec file for package libzdnn
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libzdnn
VCS: https://src.suse.de/SLFO-pool/libzdnn#1d9e1b47b7b03a9b6680be796e96d198ec78c42130e71819ae5892d3452dee4b
Version:        1.1.1
Release:        160000.3.1
Summary:        IBM Z Deep Learning Library
License:        Apache-2.0
Group:          Development/Libraries/Other
URL:            https://github.com/IBM/zDNN
Source:         zDNN-1.1.1.tar.gz
BuildRequires:  autoconf
BuildRequires:  gcc-c++

ExclusiveArch:  s390x

%description
IBM Z Deep Neural Network Library (zDNN) provides an interface for
applications making use of Neural Network Processing Assist
Facility (NNPA).

This IBM-provided C library provides a set of functions that handle
the data transformation requirements of the AIU and provide wrapper
functions for the NNPA instruction primitives.

%package -n libzdnn0
Summary:        Library interface for the IBM AI Accelerator
Group:          Development/Libraries/Other

%description -n libzdnn0
IBM Z Deep Neural Network Library (zDNN) provides an interface for
applications making use of Neural Network Processing Assist
Facility (NNPA).

This IBM-provided C library provides a set of functions that handle
the data transformation requirements of the AIU and provide wrapper
functions for the NNPA instruction primitives.

%package devel
Summary:        Deep Learning Library development files
Group:          Development/Libraries/Other
Requires:       libzdnn0 = %{version}-%{release}

%description devel
This package provides the sole include file and symbolic link to the
shared library for the libzdnn (zDNN) RPM.

%prep
%autosetup -p1 -n zDNN-%{version}

%build

autoconf
%configure
%make_build build

%install
%make_install

# We don't want/need the static library at this time. That could change.
rm -vf %{buildroot}/%{_libdir}/libzdnn.a

%post -n libzdnn0 -p /sbin/ldconfig

%postun -n libzdnn0 -p /sbin/ldconfig

%files -n libzdnn0
%doc README.md
%license LICENSE
%{_libdir}/libzdnn.so.0

%files devel
%{_includedir}/zdnn.h
%{_libdir}/libzdnn.so

%changelog
* Thu Mar 13 2025 rguenther@suse.com
- Remove BuildRequires to gcc14-c++, it's unused.
* Wed Jan 22 2025 nikolay.gueorguiev@suse.com
- Changed BuildRequires from gcc13-c++ to gcc14-c++ (jsc#PED-10257)
- Removed the exports of CC and CXX
* Mon Nov 25 2024 nikolay.gueorguiev@suse.com
- Amended the .spec file
* Fri Nov 22 2024 nikolay.gueorguiev@suse.com
- Upgrade libzdnn to version 1.1.1 (jsc#PED-11113, jsc#PED-10304, jsc#PED-10257)
  * Bump in preparation of v1.1.1
  * Fix Linux build issues
* Tue Feb 13 2024 nikolay.gueorguiev@suse.com
- Changed the Package Summary (jsc#PED-5445)
  * from 'Library interface for the IBM Cryptographic Accelerator'
  * to   'Library interface for the IBM AI Accelerator'
* Thu May 11 2023 nikolay.gueorguiev@suse.com
-  Upgraded to version 1.0.1 (jsc#PED-3331)
  - add: pull_request_template.md
    This commit adds a pullrequest template to the repository to make the PR's more uniform.
  - add: issue templates
    Templates to unify issues and descriptions with focus on traceability.
  - add: CODEOWNERS file
    Provide a fast trigger for pullrequests and assign the code owners to it.
  - fix: remove non ASCII characters
    remove non ASCII characters with focus on disclaimer and comments and licenses
    call: find . -type f -exec sed -i 's/\xC2\xA0/ /g' {} \;
    call: find . -type f -exec sed -i 's/[ \t]\+$//g' {} \;
  - add help target to main Makefile
    set default target .DEFAULT_GOAL for all
  - fix error for missing config.make to GNU make syntax
* Mon Dec 13 2021 mpost@suse.com
- Upgraded to version 0.4.0 (bsc#1191582)
  * RNN Layer 2 Support
  * RNN Bi-directional Output Transformation Support
  * Removal of non-inclusive IT Terms
  * RNN Pre-check Support
  * Optimized zTensor reserved space
  * Transform optimizations
  * Minor bug fixes
- Removed the following obsolete patches
  * sles15sp4-libzdnn-Fix-initialization-of-CFLAGS_INIT-2.patch
  * sles15sp4-libzdnn-Limit-symbol-check-to-global-symbols-3.patch
* Thu Oct 21 2021 mpost@suse.com
- Initial version of the package (jsc#SLE-21645)
  Includes the following two patches from upstream:
    sles15sp4-libzdnn-Fix-initialization-of-CFLAGS_INIT-2.patch
    sles15sp4-libzdnn-Limit-symbol-check-to-global-symbols-3.patch
